Writing new modules
=====================

In order to alter or investigate the behaviour of an algorithm it can be helpful 
to write new modules - be it an instance of one of the current module types or 
something different. In the following sections we will explore how this can be 
done. 

.. toctree::
   :maxdepth: 1

   basic_observer
   gets_basic_observer
   gets_sets_basic_observer
   two_methods_observer
   database_observer
   database_and_main_observer